@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-from distutils.spawn import find_executable
+from shutil import which
 import os
 import sys
 from django.conf import settings
@@ -8,6 +8,6 @@ __all__ = ['NODE_MODULES_ROOT', 'YARN_PATH']
 
 NODE_MODULES_ROOT = getattr(settings, 'NODE_MODULES_ROOT', os.path.abspath(os.path.dirname(__name__)))
 
-default_yarn_path = find_executable('yarnpkg') or find_executable('yarn')
+default_yarn_path = which('yarnpkg') or which('yarn')
 
 YARN_PATH = getattr(settings, 'YARN_PATH', default_yarn_path)
