@@ -6,5 +6,5 @@ class YarnNotInstalled(CommandError):
 
     def __init__(self):
         super(YarnNotInstalled, self).__init__(
-            "Yarn not installed, read instruction here - http://yarnpkg.com/",
+            "Yarn not installed, read instruction here - https://yarnpkg.com/",
         )
