@@ -1,3 +1,4 @@
+import sys
 from optparse import make_option
 from ..base import BaseYarnCommand
 
@@ -7,4 +8,5 @@ class Command(BaseYarnCommand):
 
     def handle(self, *args, **options):
         super(Command, self).handle(*args, **options)
-        self._install(args)
+        ret = self._install(args)
+        sys.exit(ret)
