@@ -1,7 +1,7 @@
 from django.core.management import call_command
 from django.conf import settings
 from django.test import TestCase
-from six import StringIO
+from io import StringIO
 from mock import MagicMock
 from ..yarn import yarn_adapter, YarnAdapter
 from .. import conf
